const expect = require('expect');
const fs = require('fs');
const path = require('path');
const Slate = require('slate');
const readMetadata = require('read-metadata');
const yaml = require('js-yaml');

const EditList = require('../lib');

describe('slate-edit-list', function() {
    const tests = fs.readdirSync(__dirname);
    const plugin = EditList();
    const schema = new Slate.Schema(plugin.schema);

    tests.forEach(function(test) {
        if (test[0] === '.' || path.extname(test).length > 0) return;

        it(test, function() {
            const dir = path.resolve(__dirname, test);
            const input = readMetadata.sync(path.resolve(dir, 'input.yaml'));
            const expected = readMetadata.sync(path.resolve(dir, 'expected.yaml'));
            const runTransform = require(path.resolve(dir, 'transform.js'));

            const stateInput = Slate.Raw.deserialize(input, { terse: true });

            const normalized = stateInput
        	    .transform()
        	    .normalize(schema)
        	    .apply();

            const normedJson = Slate.Raw.serialize(normalized, { terse: true });
            const yamlInput = yaml.dump(normedJson);

            const newState = runTransform(plugin, stateInput); //normalized);

            const newDocJSon = Slate.Raw.serialize(newState, { terse: true });

            try {
                expect(newDocJSon).toEqual(expected)
            } catch(e) {
                const result = Slate.Raw.serialize(newState, { terse: true });
                const yamlResult = yaml.dump(result);
                fs.writeFileSync(path.resolve(dir, 'cleanedInput.yml'), yamlInput, 'utf-8');
                fs.writeFileSync(path.resolve(dir, 'actualOutput.yml'), yamlResult, 'utf-8');
            }
            
            expect(newDocJSon).toEqual(expected);
        });
    });
});
