'use strict';

var Slate = require('slate');

var _require = require('immutable'),
    List = _require.List;

var TablePosition = require('../TablePosition');

/**
 * Delete current column in a table
 *
 * @param {Object} opts
 * @param {Slate.Transform} transform
 * @param {Number} at
 * @return {Slate.Transform}
 */
function removeColumn(opts, transform, at) {
    var state = transform.state;
    var startBlock = state.startBlock;


    var pos = TablePosition.create(state, startBlock, opts);
    var table = pos.table;


    if (typeof at === 'undefined') {
        at = pos.getColumnIndex();
    }

    var rows = table.nodes;

    // Remove the cell from every row
    if (pos.getWidth() > 1) {
        rows.forEach(function (row) {
            var cell = row.nodes.get(at);
            transform.removeNodeByKey(cell.key);
        });
    }
    // If last column, clear text in cells instead
    else {
            rows.forEach(function (row) {
                row.nodes.forEach(function (cell) {
                    // remove existing children
                    cell.nodes.forEach(function (node) {
                        transform.removeNodeByKey(node.key);
                    });
                    // add the empty child content node
                    var emptyChild = Slate.Block.create({
                        type: opts.typeContent,
                        nodes: [Slate.Raw.deserializeText({
                            kind: 'text',
                            text: ''
                        }, { terse: true })]
                    });
                    transform.insertNodeByKey(cell.key, 0, emptyChild);
                });
            });
        }

    // Replace the table
    return transform;
}

module.exports = removeColumn;